Update of /cvsroot/audacity/audacity-src/src
In directory sc8-pr-cvs11.sourceforge.net:/tmp/cvs-serv21499

Modified Files:
        TrackArtist.cpp 
Log Message:
Attempt to make the 'before zero' arrows more obvious.  Really need to be 
wider, I feel.

Index: TrackArtist.cpp
===================================================================
RCS file: /cvsroot/audacity/audacity-src/src/TrackArtist.cpp,v
retrieving revision 1.102
retrieving revision 1.103
diff -u -d -r1.102 -r1.103
--- TrackArtist.cpp     14 Sep 2007 21:48:49 -0000      1.102
+++ TrackArtist.cpp     26 Sep 2007 23:01:10 -0000      1.103
@@ -542,11 +542,11 @@
 
 void TrackArtist::DrawNegativeOffsetTrackArrows(wxDC &dc, wxRect &r)
 {
    // Draws two white arrows on the left side of the track to
    // indicate the user that the track has been time-shifted
    // to the left beyond t=0.0.
 
-   dc.SetPen(*wxWHITE_PEN);
+   dc.SetPen(*wxBLACK_PEN);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 8, r.y + 6);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 6, r.y + 2);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 6, r.y + 10);


-------------------------------------------------------------------------
@@ -542,11 +542,11 @@
 void TrackArtist::DrawNegativeOffsetTrackArrows(wxDC &dc, wxRect &r)
 {
-   // Draws two white arrows on the left side of the track to
+   // Draws two black arrows on the left side of the track to
    // indicate the user that the track has been time-shifted
    // to the left beyond t=0.0.
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
_______________________________________________
Audacity-cvs mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/audacity-cvs

Reply via email to